GraphState class

The state of the graph.

Constructors

GraphState({required List<InputNode> nodes})

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodes → List<InputNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<InputNode>? nodes}) → GraphState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited