describeResult method
Override this to provide a customized description of the result. This is used by the built-in observers for improved logging.
Implementation
@useResult
String describeResult(R result) {
return defaultDescribe(result);
}
Override this to provide a customized description of the result. This is used by the built-in observers for improved logging.
@useResult
String describeResult(R result) {
return defaultDescribe(result);
}