SendActionAction class

Sends an action to the client.

Constructors

SendActionAction({required String actionId, required Map<String, dynamic> params})

Properties

actionId → String
final
debugLabel → String
The debug label of the action. Override this getter to provide a custom label.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
notifier → InspectorServer
Access the notifier to access other notifiers.
no setterinherited
notifierType → Type
no setterinherited
params → Map<String, dynamic>
final
refenaId → int
The id.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ServerState
Returns the current state of the notifier.
no setterinherited
trackOrigin → bool
Whether the ActionDispatchedEvent should have the ActionDispatchedEvent.debugOriginRef of the origin of the action. This is true by default for better visualization in the tracing page.
no setterinherited

Methods

after() → void
Override this to have some logic after the action is dispatched. This method is called even if before or reduce throws.
inherited
before() → void
See BaseReduxAction.before for documentation.
inherited
compareIdentity(IdReference other) → bool
Returns true, if the other reference has the same id.
inherited
describeResult(void result) → String
Override this to provide a customized description of the result. This is used by the built-in observers for improved logging.
inherited
dispatch(SynchronousReduxAction<InspectorServer, ServerState, dynamic> action, {String? debugOrigin}) → ServerState
Dispatches a synchronous action and updates the state. Returns the new state.
inherited
dispatchAsync(AsynchronousReduxAction<InspectorServer, ServerState, dynamic> action, {String? debugOrigin}) → Future<ServerState>
Dispatches an asynchronous action and updates the state. Returns the new state.
inherited
dispatchAsyncTakeResult<R2>(BaseAsyncReduxActionWithResult<InspectorServer, ServerState, R2> action, {String? debugOrigin}) → Future<R2>
Dispatches an asynchronous action and updates the state. Returns only the result of the action.
inherited
dispatchAsyncWithResult<R2>(BaseAsyncReduxActionWithResult<InspectorServer, ServerState, R2> action, {String? debugOrigin}) → Future<(ServerState, R2)>
Dispatches an asynchronous action and updates the state. Returns the new state along with the result of the action.
inherited
dispatchTakeResult<R2>(BaseReduxActionWithResult<InspectorServer, ServerState, R2> action, {String? debugOrigin}) → R2
Dispatches an action and updates the state. Returns only the result of the action.
inherited
dispatchWithResult<R2>(BaseReduxActionWithResult<InspectorServer, ServerState, R2> action, {String? debugOrigin}) → (ServerState, R2)
Dispatches an action and updates the state. Returns the new state along with the result of the action.
inherited
emitMessage(String message) → void
Emits a message to the observer.
inherited
external<T2>(ReduxNotifier<T2> notifier) → Dispatcher<ReduxNotifier<T2>, T2>
Use this method to dispatch external actions within an action. This ensures that the dispatched action has the correct debugOrigin.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce() → ServerState
The method that returns the new state.
toString() → String
A string representation of this object.
inherited
wrapReduce() → ServerState
Override this to have some logic before and after the reduce method. Specifically, this method is called after before and before after: before -> wrapReduce -> after
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited