ServerState class

The state of the server.

Constructors

ServerState({required bool running, required bool clientConnected, required WebSocketSink? sink})

Properties

clientConnected → bool
final
hashCode → int
The hash code for this object.
no setterinherited
running → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink → WebSocketSink?
final

Methods

copyWith({bool? running, bool? clientConnected, WebSocketSink? sink}) → ServerState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited